@@ -5,34 +5,23 @@
 */
 
 #include "appletquickitem.h"
-#include "applet.h"
-#include "appletcontext_p.h"
 #include "appletquickitem_p.h"
-#include "configview.h"
+
+#include "appletcontext_p.h"
 #include "containment.h"
 #include "debug_p.h"
-#include "plasma_version.h"
 #include "plasmoid/containmentitem.h"
 #include "plasmoid/plasmoiditem.h"
-#include "plasmoid/wallpaperitem.h"
-#include "plasmoidattached_p.h"
 #include "sharedqmlengine.h"
 
 #include <QJsonArray>
-#include <QQmlContext>
-#include <QQmlExpression>
 #include <QQmlProperty>
-#include <QQuickWindow>
 #include <QRandomGenerator>
-
-#include <QDebug>
+#include <QTimer>
 
 #include <KLocalizedString>
 
-#include <Plasma/Applet>
-#include <Plasma/Containment>
-#include <Plasma/Corona>
-#include <qquickitem.h>
+using namespace Qt::StringLiterals;
 
 namespace PlasmaQuick
 {
@@ -242,14 +231,18 @@ QQuickItem *AppletQuickItemPrivate::createCompactRepresentationExpanderItem()
         return compactRepresentationExpanderItem;
     }
 
-    compactRepresentationExpanderItem = qobject_cast<QQuickItem *>(qmlObject->createObjectFromComponent(compactRepresentationExpander, qmlContext(q)));
+    // Ensure plasmoidItem is not null on creation to avoid ternary operator in QML
+    compactRepresentationExpanderItem = qobject_cast<QQuickItem *>(qmlObject->createObjectFromComponent(compactRepresentationExpander,
+                                                                                                        qmlContext(q),
+                                                                                                        {
+                                                                                                            {u"plasmoidItem"_s, QVariant::fromValue(q)},
+                                                                                                        }));
 
     if (!compactRepresentationExpanderItem) {
         return nullptr;
     }
 
     compactRepresentationExpanderItem->setProperty("compactRepresentation", QVariant::fromValue<QObject *>(createCompactRepresentationItem()));
-    compactRepresentationExpanderItem->setProperty("plasmoidItem", QVariant::fromValue(q));
 
     return compactRepresentationExpanderItem;
 }
@@ -271,7 +264,7 @@ bool AppletQuickItemPrivate::appletShouldBeExpanded() const
             // size, and the full representation preferred size.
             // this can cause in the panel (when is quite big) an infinite resize loop, because
             // the applet size is bigger than the switch size, then it switches to full
-            // representaiton that has a smaller hint. this causes a resize that will make it
+            // representation that has a smaller hint. this causes a resize that will make it
             // switch to compact representation, making it grow again and switch again
             if (compactRepresentationItem && fullRepresentationItem) {
                 QObject *compactLayout = searchLayoutAttached(compactRepresentationItem);
@@ -509,17 +502,6 @@ AppletQuickItem *AppletQuickItem::itemForApplet(Plasma::Applet *applet)
         return nullptr;
     }
 
-    // TODO: move somewhere else? in plasmacore import?
-    if (AppletQuickItemPrivate::s_itemsForApplet.isEmpty()) {
-        const char *uri = "org.kde.plasma.plasmoid";
-        qmlRegisterExtendedType<Plasma::Applet, PlasmoidAttached>(uri, 2, 0, "Plasmoid");
-        qmlRegisterExtendedType<Plasma::Containment, ContainmentAttached>(uri, 2, 0, "Containment");
-
-        qmlRegisterType<PlasmoidItem>(uri, 2, 0, "PlasmoidItem");
-        qmlRegisterType<ContainmentItem>(uri, 2, 0, "ContainmentItem");
-        qmlRegisterType<WallpaperItem>(uri, 2, 0, "WallpaperItem");
-        qmlRegisterAnonymousType<Plasma::Corona>("org.kde.plasma.plasmoid", 1);
-    }
     auto it = AppletQuickItemPrivate::s_itemsForApplet.constFind(applet);
     if (it != AppletQuickItemPrivate::s_itemsForApplet.constEnd()) {
         return it.value();
@@ -663,7 +645,7 @@ AppletQuickItem *AppletQuickItem::itemForApplet(Plasma::Applet *applet)
 
     QObject::connect(applet, &Plasma::Applet::appletDeleted, item, [qmlObject](Plasma::Applet *applet) {
         // Deleting qmlObject will also delete the instantiated plasmoidItem
-        // deleteing just the plasmoiditem will cause a double deletion when qmlObject
+        // deleting just the plasmoiditem will cause a double deletion when qmlObject
         // gets deleted by applet deletion
         if (qmlObject->parent() == applet) {
             // appletDelete can also be emitted by a containment for one of its children
